@@ -50,6 +50,26 @@ class KSCREEN_EXPORT Config : public QObject
     Q_PROPERTY(OutputList outputs READ outputs)
 
   public:
+    enum class ValidityFlag {
+        None = 0x0,
+        RequireAtLeastOneEnabledScreen = 0x1
+    };
+    Q_DECLARE_FLAGS(ValidityFlags, ValidityFlag)
+
+    /**
+     * Validates that a config can be applied in the current system
+     *
+     * Each system has different constrains, this method will test
+     * the given config with those constrains to see if it
+     * can be applied.
+     *
+     * @arg config to be checked
+     * @flags enable additional optional checks
+     * @return true if the configuration can be applied, false if not.
+     * @since 5.3.0
+     */
+    static bool canBeApplied(const ConfigPtr &config, ValidityFlags flags);
+
     /**
      * Validates that a config can be applied in the current system
      *
@@ -109,8 +129,6 @@ class KSCREEN_EXPORT Config : public QObject
 
     class Private;
     Private * const d;
-
-    Config(Private *dd);
 };
 
 } //KScreen namespace
