@@ -1,25 +1,25 @@
 /*************************************************************************************
  *  Copyright (C) 2012 by Alejandro Fiestas Olivares <afiestas@kde.org>              *
+ *  Copyright (C) 2014 by Daniel Vrátil <dvratil@redhat.com>                         *
  *                                                                                   *
- *  This program is free software; you can redistribute it and/or                    *
- *  modify it under the terms of the GNU General Public License                      *
- *  as published by the Free Software Foundation; either version 2                   *
- *  of the License, or (at your option) any later version.                           *
+ *  This library is free software; you can redistribute it and/or                    *
+ *  modify it under the terms of the GNU Lesser General Public                       *
+ *  License as published by the Free Software Foundation; either                     *
+ *  version 2.1 of the License, or (at your option) any later version.               *
  *                                                                                   *
- *  This program is distributed in the hope that it will be useful,                  *
+ *  This library is distributed in the hope that it will be useful,                  *
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                    *
- *  GNU General Public License for more details.                                     *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU                *
+ *  Lesser General Public License for more details.                                  *
  *                                                                                   *
- *  You should have received a copy of the GNU General Public License                *
- *  along with this program; if not, write to the Free Software                      *
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA   *
+ *  You should have received a copy of the GNU Lesser General Public                 *
+ *  License along with this library; if not, write to the Free Software              *
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA       *
  *************************************************************************************/
 
 #include "mode.h"
 
-namespace KScreen {
-
+using namespace KScreen;
 class Mode::Private
 {
   public:
@@ -27,24 +27,43 @@ class Mode::Private
       rate(0)
     { }
 
+    Private(const Private &other):
+        id(other.id),
+        name(other.name),
+        size(other.size),
+        rate(other.rate)
+    {
+    }
+
     QString id;
     QString name;
     QSize size;
     float rate;
 };
 
-Mode::Mode(QObject *parent)
-  : QObject(parent)
+Mode::Mode()
+  : QObject(0)
   , d(new Private())
 {
 
 }
 
+Mode::Mode(Mode::Private *dd)
+  : QObject()
+  , d(dd)
+{
+}
+
 Mode::~Mode()
 {
     delete d;
 }
 
+ModePtr Mode::clone() const
+{
+    return ModePtr(new Mode(new Private(*d)));
+}
+
 const QString Mode::id() const
 {
     return d->id;
@@ -110,6 +129,13 @@ void Mode::setRefreshRate(float refresh)
     Q_EMIT modeChanged();
 }
 
-} //KScreen namespace
 
-#include "mode.moc"
+QDebug operator<<(QDebug dbg, const KScreen::ModePtr &mode)
+{
+    if (mode) {
+        dbg << "KScreen::Mode(Id:" << mode->id() << ", Size:" << mode->size() << ")";
+    }  else {
+        dbg << "KScreen::Mode(NULL)";
+    }
+    return dbg;
+}
